CheckpointManager

pub struct CheckpointManager { /* private fields */ }
Manages checkpoints for a single execution.

Implementations

Source

impl CheckpointManager

pub fn new(execution_id: &str) -> Self

Create a new checkpoint manager for an execution.

pub fn initialize(&mut self, payload: &str) -> OperationEvents

Initialize with the first operation (EXECUTION type).

pub fn get_operation_data(&self, operation_id: &str) -> Option<&OperationEvents>

Get operation data by ID.

pub fn get_all_operation_data(&self) -> &HashMap<String, OperationEvents>

Get all operation data.

pub fn has_dirty_operations(&self) -> bool

Check if there are dirty operations.

pub fn get_dirty_operations(&mut self) -> Vec<Operation>

Get and clear dirty operations.

pub fn is_execution_completed(&self) -> bool

Check if execution is completed.

pub fn start_invocation(&mut self, invocation_id: &str) -> Vec<OperationEvents>

Start an invocation.

pub fn complete_invocation( &mut self, invocation_id: &str, ) -> Result<InvocationTimestamps, TestError>

Complete an invocation.

pub fn get_state(&self) -> Vec<Operation>

Get current state (all operations in insertion order).

pub fn process_checkpoint( &mut self, updates: Vec<OperationUpdate>, ) -> Result<Vec<Operation>, TestError>

Process a checkpoint with operation updates.

pub fn callback_manager(&self) -> &CallbackManager

Get the callback manager.

pub fn callback_manager_mut(&mut self) -> &mut CallbackManager

Get mutable callback manager.

pub fn complete_callback_operation( &mut self, callback_id: &str, result: Option<String>, error: Option<ErrorObject>, )

Complete a callback operation by updating its status and result/error.

Finds the operation whose callback_details.callback_id matches the given callback_id and transitions it to Succeeded (with result) or Failed (with error). This is called when an external system sends a callback response via the CallbackManager.

pub fn event_processor(&self) -> &EventProcessor

Get the event processor.

pub fn event_processor_mut(&mut self) -> &mut EventProcessor

Get mutable event processor.

pub fn get_history_events(&self) -> Vec<HistoryEvent>

Get all history events.

pub fn get_nodejs_history_events(&self) -> Vec<NodeJsHistoryEvent>

Get all Node.js-compatible history events.

Returns a vector of events in the Node.js SDK compatible format, suitable for cross-SDK history comparison.

pub fn execution_id(&self) -> &str

Get the execution ID.

pub fn update_operation_data( &mut self, operation_id: &str, updated_operation: Operation, )

Update operation data directly.

This method is used by the orchestrator to update operation state (e.g., marking wait operations as SUCCEEDED after time advancement).