Checkpoint token encoding and decoding utilities.
This module provides utilities for encoding and decoding checkpoint tokens, which are used to track the state of an execution across invocations.
Structs
- Checkpoint
Token Data - Data contained in a checkpoint token.
Functions
- decode_
checkpoint_ token - Decode a checkpoint token string to data.
- encode_
checkpoint_ token - Encode checkpoint token data to a base64 string.