Module execution_manager

Module execution_manager 

Execution manager for managing the state of all executions.

This module implements the ExecutionManager which manages the state of all executions, with each execution having its own CheckpointManager.

Structs

CompleteInvocationResponse
Response from completing an invocation.
ExecutionManager
Manages all execution states.
InvocationResult
Result of starting an invocation.
StartExecutionParams
Parameters for starting an execution.