pub struct Invocation {
pub start_timestamp: Option<DateTime<Utc>>,
pub end_timestamp: Option<DateTime<Utc>>,
pub request_id: Option<String>,
pub error: Option<TestResultError>,
}Expand description
Information about a single handler invocation.
Tracks timing and error information for each time the handler was invoked during a durable execution.
Examples
use durable_execution_sdk_testing::Invocation;
let invocation = Invocation::new();
assert!(invocation.start_timestamp.is_none());
assert!(invocation.error.is_none());Fields
start_timestamp: Option<DateTime<Utc>>Timestamp when the invocation started
end_timestamp: Option<DateTime<Utc>>Timestamp when the invocation ended
request_id: Option<String>Request ID for this invocation (e.g., Lambda request ID)
error: Option<TestResultError>Error information if the invocation failed
Implementations
Sourceimpl Invocation
impl Invocation
Sourcepub fn with_start(start: DateTime<Utc>) -> Self
pub fn with_start(start: DateTime<Utc>) -> Self
Creates a new Invocation with the given start timestamp.
Sourcepub fn with_request_id(self, request_id: impl Into<String>) -> Self
pub fn with_request_id(self, request_id: impl Into<String>) -> Self
Sets the request ID.
Sourcepub fn with_error(self, error: TestResultError) -> Self
pub fn with_error(self, error: TestResultError) -> Self
Sets the error.