Checkpoint manager for managing checkpoints of a single execution.
This module implements the CheckpointManager which manages checkpoints for a single execution, including operation state, callback lifecycle, and history events, matching the Node.js SDK’s checkpoint manager.
Structs
- Checkpoint
Manager - Manages checkpoints for a single execution.
- Checkpoint
Operation - A checkpoint operation with update tracking.
- Invocation
Timestamps - Timestamps for an invocation.
- Operation
Events - Operation with associated event data.