Execution manager for managing the state of all executions.
This module implements the ExecutionManager which manages the state of all executions, with each execution having its own CheckpointManager.
Structs
- Complete
Invocation Response - Response from completing an invocation.
- Execution
Manager - Manages all execution states.
- Invocation
Result - Result of starting an invocation.
- Start
Execution Params - Parameters for starting an execution.