pub struct QueueScheduler { /* private fields */ }Expand description
Queue-based scheduler for time-skipping mode.
Executes functions sequentially in FIFO order, ignoring timestamps. This is used when time skipping is enabled to process operations as quickly as possible without waiting for actual time to pass.
Implementations