Lazy operation handle for pre-run operation registration.
An OperationHandle is a lazy reference to a named operation that is registered
before run() and auto-populates with operation data during execution. This enables
the idiomatic callback testing pattern: pre-register a handle, start a non-blocking
run, wait for mid-execution status changes, send callback responses, and await the
final result.
Structs
- Operation
Handle - A lazy handle to an operation that will be populated during execution.
Enums
- Operation
Matcher - How an
OperationHandlematches against operations during execution.